@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Email::Sender::Manual::QuickStart;
 BEGIN {
-  $Email::Sender::Manual::QuickStart::VERSION = '0.102360';
+  $Email::Sender::Manual::QuickStart::VERSION = '0.110000';
 }
 # ABSTRACT: how to start using Email::Sender right now
 
@@ -18,7 +18,7 @@ Email::Sender::Manual::QuickStart - how to start using Email::Sender right now
 
 =head1 VERSION
 
-version 0.102360
+version 0.110000
 
 =head1 QUICK START
 
@@ -149,7 +149,7 @@ respected >>.  If you set the default transport via the environment, that's it.
 Everything will use that transport.  (Also, note that while we gave the host and
 port arguments above in lower case, the casing of arguments in the environment
 is flattened to support systems where environment variables are of a fixed
-case.  So, C<EMAIL_SENDER_TRANSPORT_PORT> woudl also work.
+case.  So, C<EMAIL_SENDER_TRANSPORT_PORT> would also work.
 
 This is extremely valuable behavior, as it allows you to audit every message
 that would be sent by a program by running something like this:
@@ -201,7 +201,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2011 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
